/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.catalina.ha;

import org.apache.catalina.Valve;

/**
 * Cluster valves are a simple extension to the Tomcat valve architecture with a small addition of being able to
 * reference the cluster component in the container it sits in.
 *
 * @author Peter Rossbach
 */
public interface ClusterValve extends Valve {
    /**
     * Returns the cluster the valve is associated with
     *
     * @return CatalinaCluster
     */
    CatalinaCluster getCluster();

    /**
     * Associates the cluster deployer with a cluster
     *
     * @param cluster CatalinaCluster
     */
    void setCluster(CatalinaCluster cluster);
}
