/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jasper.runtime;

import java.util.Map;

/**
 * Interface for tracking the source files dependencies, for the purpose of compiling out of date pages. This is used
 * for:
 * <ul>
 * <li>files that are included by page directives</li>
 * <li>files that are included by include-prelude and include-coda in jsp:config</li>
 * <li>files that are tag files and referenced</li>
 * <li>TLDs referenced</li>
 * </ul>
 */

public interface JspSourceDependent {

    /**
     * Returns a map of file names and last modified time where the current page has a source dependency on the file.
     *
     * @return the map of dependent resources
     */
    Map<String,Long> getDependants();
}